# Security Policy

## Supported Versions

Only the latest released version receives security updates.

## Reporting a Vulnerability

**Do not open a public issue for security vulnerabilities.**

Email **security@pioneers.ai** with:

- Description of the vulnerability
- Steps to reproduce
- Potential impact

We will acknowledge your report within 48 hours and provide a timeline for a fix.

## Disclosure

We follow coordinated disclosure. We ask that you give us reasonable time to address the issue before publishing details.
